@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,8 +55,11 @@ import java.util.List;
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
+import org.apache.commons.fileupload.FileUploadBase;
+import org.apache.commons.fileupload.servlet.ServletRequestContext;
 import com.openexchange.ajax.MultipleAdapterServletNew;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.messaging.MessagingContent;
 import com.openexchange.messaging.MessagingException;
 import com.openexchange.messaging.MessagingMessageAccess;
@@ -74,45 +77,50 @@ import com.openexchange.tools.session.ServerSession;
  */
 public class MessagesServlet extends MultipleAdapterServletNew {
 
-    
+    /**
+     *
+     */
+    private static final long serialVersionUID = 2342329232570692011L;
+
     private static final Object RESOLVE = "resolve";
-    private List<MessagingContentDumper> dumpers = new ArrayList<MessagingContentDumper>(1) {{
-        add(new BinaryContentDumper());
-        // Add more as needed
-    }};
+
+    private final List<MessagingContentDumper> dumpers;
 
     public MessagesServlet() {
         super(MessagingActionFactory.INSTANCE);
+        dumpers = new ArrayList<MessagingContentDumper>(1);
+        dumpers.add(new BinaryContentDumper());
     }
-    
+
     @Override
-    protected boolean hasModulePermission(ServerSession session) {
-        return true; 
+    protected boolean hasModulePermission(final ServerSession session) {
+        return true;
     }
-    
+
     @Override
-    protected boolean handleIndividually(String action, HttpServletRequest req, HttpServletResponse resp) throws IOException, ServletException {
+    protected boolean handleIndividually(final String action, final HttpServletRequest req, final HttpServletResponse resp) throws IOException, ServletException, AbstractOXException {
         if(RESOLVE.equals(action)) {
-            AJAXRequestData requestData = parseRequest(req, false);
-            MessagingRequestData request = MessagingActionFactory.INSTANCE.wrapRequest(requestData, getSessionObject(req));
-            
+            final ServerSession session = getSessionObject(req);
+            final AJAXRequestData requestData = parseRequest(req, false, FileUploadBase.isMultipartContent(new ServletRequestContext(req)), session);
+            final MessagingRequestData request = MessagingActionFactory.INSTANCE.wrapRequest(requestData, session);
+
             try {
-                MessagingMessageAccess messageAccess = request.getMessageAccess();
-                
-                MessagingContent content = messageAccess.resolveContent(request.getFolderId(), request.getId(), request.getReferenceId());
-                
+                final MessagingMessageAccess messageAccess = request.getMessageAccess(session.getUserId(), session.getContextId());
+
+                final MessagingContent content = messageAccess.resolveContent(request.getFolderId(), request.getId(), request.getReferenceId());
+
                 //TODO: Set Content-Type Header
-                for(MessagingContentDumper dumper : dumpers) {
+                for(final MessagingContentDumper dumper : dumpers) {
                     if(dumper.handles(content)) {
                         dumper.dump(content, resp.getOutputStream());
                     }
                 }
-                
-                
-            } catch (MessagingException e) {
+
+
+            } catch (final MessagingException e) {
                 throw new ServletException(e);
             }
-            
+
             return true;
         }
         return super.handleIndividually(action, req, resp);
